@@ -8,7 +8,9 @@ test -n "${gitlab_user}" || gitlab_user="gitlab"
 
 # Create gitlab user with home in /var/lib
 echo "Creating/updating ${gitlab_user} user account..."
-adduser --home /var/lib/${gitlab_user} --gecos "${gitlab_user} user" --shell /bin/sh \
-	--quiet --disabled-password ${gitlab_user} || {
+adduser --system --home /var/lib/${gitlab_user} --gecos "${gitlab_user} user" --shell /bin/sh \
+	--quiet --disabled-password --group ${gitlab_user} || {
 echo "Proceeding with existing ${gitlab_user} user..."
   }
+echo "Making ${gitlab_user} owner of /var/lib/${gitlab_user}..."
+chown -R ${gitlab_user} /var/lib/${gitlab_user}
